(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     12996,        323]*)
(*NotebookOutlinePosition[     13704,        347]*)
(*  CellTagsIndexPosition[     13660,        343]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
Concepts and Methods of 2D Infrared Spectroscopy
Peter Hamm and Martin T. Zanni\
\>", "Section"],

Cell[CellGroupData[{

Cell["\<\
This progam was used to produce Figs. 10.3, 10.4, and 10.5, i.e. the 2D IR \
lineshape of the OH stretch vibration in water, using the Cumulant expansion  \
\
\>", "Subsubtitle"],

Cell["Set working directory (you will have to change it)", "Text"],

Cell[BoxData[
    \(\(SetDirectory["\<C:\Dokumente und Einstellungen\p.hamm\Eigene \
Dateien/PCI/projekte/2010/2D-IR Book/SecSimul/SimulWater\>"];\)\)], "Input"],

Cell["\<\
Constants and proportionaltiy factor that translates forces into a frequency \
shift (Eq. 10.4)\
\>", "Text"],

Cell[BoxData[{
    \(\(NA = 6.023*10^23;\)\), "\[IndentingNewLine]", 
    \(\(w0 = 3550;\)\), "\[IndentingNewLine]", 
    \(\(mass = 1.66*10^\(-27\);\)\), "\[IndentingNewLine]", 
    \(\(mH = 1. ;\)\), "\[IndentingNewLine]", 
    \(\(mO = 16. ;\)\), "\[IndentingNewLine]", 
    \(\(mu = mH*mO/\((mH + mO)\);\)\), "\[IndentingNewLine]", 
    \(\(c = 3*10^10;\)\), "\[IndentingNewLine]", 
    \(\(h = 6.626*10^\(-34\);\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalDelta] = 240;\)\), "\[IndentingNewLine]", 
    \(\(fact = 
        Sqrt[9/4 \((\[CapitalDelta]/
                  w0)\)\ 10^18*\(\(10^6/NA^2\)/\((w0*c*h)\)\)/\((mu*
                    mass)\)*10^\(-24\)]/ .188;\)\)}], "Input"],

Cell["Read MD output files generated by Gromacs (see README file)", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"coord", "=", " ", 
        RowBox[{
          StyleBox["ReadList",
            "MR"], 
          "[", \("\<coord.xvg\>", {Real, Real, Real, Real, Real, Real, 
            Real}\), "]"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"force", "=", " ", 
        RowBox[{
          StyleBox["ReadList",
            "MR"], 
          "[", \("\<force.xvg\>", {Real, Real, Real, Real, Real, Real, 
            Real}\), "]"}]}], ";"}]}], "Input"],

Cell["Calculate frequency shift according to Eqs. 10.2 and 10.4", "Text"],

Cell[BoxData[{
    \(\(n = Length[force];\)\), "\[IndentingNewLine]", 
    \(\(dt = \((force[\([2, 1]\)] - 
            force[\([1, 1]\)])\);\)\), "\[IndentingNewLine]", 
    \(\(bondOH = 
        Table[{coord[\([i, 5]\)] - coord[\([i, 2]\)], 
            coord[\([i, 6]\)] - coord[\([i, 3]\)], 
            coord[\([i, 7]\)] - coord[\([i, 4]\)]}\ , {i, 1, 
            n}];\)\), "\[IndentingNewLine]", 
    \(\(length = 
        Sqrt[bondOH[\([1, 1]\)]^2 + bondOH[\([1, 2]\)]^2 + 
            bondOH[\([1, 3]\)]^2];\)\), "\[IndentingNewLine]", 
    \(\(forceOH = 
        Table[{\((force[\([i, 5]\)]/mH - force[\([i, 2]\)]/mO)\)*
              mu, \((force[\([i, 6]\)]/mH - force[\([i, 3]\)]/mO)\)*
              mu, \((force[\([i, 7]\)]/mH - force[\([i, 4]\)]/mO)\)*
              mu}\ , {i, 1, n}];\)\), "\[IndentingNewLine]", 
    \(\(w = 
        w0 - Table[\((forceOH[\([i, 1]\)]*bondOH[\([i, 1]\)] + 
                    forceOH[\([i, 2]\)]*bondOH[\([i, 2]\)] + 
                    forceOH[\([i, 3]\)]*bondOH[\([i, 3]\)])\), {i, 1, n}]/
              length*fact;\)\)}], "Input"],

Cell["Plot a piece of the frequency trajectory (Fig. 10.3a) ", "Text"],

Cell[BoxData[{
    \(\(wmin = 3000;\)\), "\[IndentingNewLine]", 
    \(\(wmax = 3600;\)\), "\[IndentingNewLine]", 
    \(\(Table[{i\ dt, w[\([i]\)]}, {i, 1, 500}];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[%, PlotJoined \[Rule] True, PlotRange \[Rule] {wmin, wmax}, 
        Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<Time[ps]\>", "\<Frequency[cm-1]\>"}];\)\)}], \
"Input"],

Cell["Calculate frequency distribution (Fig. 10.3b)", "Text"],

Cell[BoxData[{
    \(\(nd = 50;\)\), "\[IndentingNewLine]", 
    \(\(dist = Table[0. , {i, 1, nd}];\)\), "\[IndentingNewLine]", 
    \(\(For[i = 1, i \[LessEqual] n, \(i++\), 
        dist[\([Floor[\((w[\([i]\)] - wmin)\)/\((wmax - wmin)\)*nd]]\)] += 
          1];\)\), "\[IndentingNewLine]", 
    \(\(dist = 
        Table[{wmin + i \((wmax - wmin)\)/nd, dist[\([i]\)]}, {i, 1, 
            nd}];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[dist, PlotRange \[Rule] {{wmin, wmax}, {0, Max[dist]*1.1}}, 
        PlotJoined \[Rule] True, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<Frequency[cm-1]\>", None}, 
        FrameTicks \[Rule] {True, False, False, False}];\)\)}], "Input"],

Cell["\<\
Calculate Frequency Fluctuation Correlation Function (FFCF, Fig. 10.3.c)\
\>", "Text"],

Cell[BoxData[{
    \(\(ncorr = 150;\)\), "\[IndentingNewLine]", 
    \(\(wmean = Sum[w[\([i]\)], {i, 1, n}]/n;\)\), "\[IndentingNewLine]", 
    \(\(corr = 
        Table[{i*dt, 
            Sum[\((w[\([iti]\)] - wmean)\)*\((w[\([iti + i]\)] - 
                        wmean)\), {iti, 1, n - ncorr, 5}]/\((n - 
                    ncorr)\)*5* .188^2}, {i, 0, 
            ncorr - 1}];\)\), "\[IndentingNewLine]", 
    \(ListPlot[corr, PlotJoined \[Rule] True, PlotRange \[Rule] {0, 300}, 
      Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<Time[ps]\>", "\<<dw(t)dw(0)> [ps-2]\>"}]\)}], \
"Input"],

Cell["\<\
Fit the FFCF to an analytic function in order to calculate a line shape \
function\
\>", "Text"],

Cell[BoxData[{\(<< Statistics`NonlinearFit`\), "\[IndentingNewLine]", \(fit = 
      NonlinearFit[corr, 
        a1\ Cos[w00\ t] Exp[\(-t\)/\[Tau]1] + a2\ Exp[\(-t\)/\[Tau]2] + 
          a3\ Exp[\(-t\)/\[Tau]3], 
        t, {{a1, 100}, {w00, 3}, {\[Tau]1,  .05}, {a2, 
            100}, {\[Tau]2,  .1}, {a3, 50}, {\[Tau]3, 
            1}}]\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(g[tau2_]\), "=", 
        RowBox[{"Simplify", "[", 
          RowBox[{
          "Chop", "[", \(Integrate[
              Integrate[fit, {t, 0, tau1}\ ], {tau1, 0, tau2}]\), 
            StyleBox[" ",
              "MR"], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", \(Plot[
      fit, {t, 0, 1.5}, PlotRange \[Rule] {0, 300}]\)}], "Input"],

Cell["\<\
Define response functions for rephasing and non-rephasing diagrams for a \
three-level system (Equ. 7.40). The factor 0.188 is to convert a frequency in \
cm-1 into one in ps-1.\
\>", "Text"],

Cell[BoxData[{
    \(\(Rnr = \((Exp[\(-I\) \((t3 + t1)\) wmean* .188] - 
              Exp[\(-I\)\ \((t3\ \((wmean* .188 - \[CapitalDelta]* .188)\) + 
                      t1\ wmean* .188)\)]\ )\)*
          Exp[\(-g[t1]\) - g[t2] - g[t3] + g[t1 + t2] + g[t2 + t3] - 
              g[t1 + t2 + t3]];\)\), "\[IndentingNewLine]", 
    \(\(Rr = \((Exp[\(-I\) \((t3 - t1)\) wmean* .188] - 
              Exp[\(-I\) \((t3\ \((wmean* .188 - \[CapitalDelta]* .188)\) - 
                      t1\ wmean* .188)\)]\ )\)*
          Exp[\(-g[t1]\) + g[t2] - g[t3] - g[t1 + t2] - g[t2 + t3] + 
              g[t1 + t2 + t3]];\)\)}], "Input"],

Cell["\<\
Collect rephasing and non-rephasing data on a grid with stepsize dt and nt \
data points with population time t2.The first time-point needs to be halved \
(Sect.9.5.3).\
\>", "Text"],

Cell[BoxData[{
    \(\(t2 =  .5;\)\), "\[IndentingNewLine]", 
    \(\(nt = 512;\)\), "\[IndentingNewLine]", 
    \(\(dt =  .0025;\)\), "\[IndentingNewLine]", 
    \(\(Rnrlist = 
        Table[Rnr, {t1, 0, \((nt - 1)\)*dt, dt}, {t3, 0, \((nt - 1)\)*dt, 
            dt}];\)\), "\[IndentingNewLine]", 
    \(\(Rrlist = 
        Table[Rr, {t1, 0, \((nt - 1)\)*dt, dt}, {t3, 0, \((nt - 1)\)*dt, 
            dt}];\)\), "\[IndentingNewLine]", 
    \(\(For[i = 1, i <= nt, \(i++\), Rnrlist[\([i, 1]\)] /= 2; 
        Rrlist[\([i, 1]\)] /= 2];\)\), "\[IndentingNewLine]", 
    \(\(For[i = 2, i <= nt, \(i++\), Rnrlist[\([1, i]\)] /= 2; 
        Rrlist[\([1, i]\)] /= 2];\)\)}], "Input"],

Cell["Plot time-domain data (Fig. 10.4)", "Text"],

Cell[BoxData[{
    \(\(ticks = 
        Table[{t/dt, t*1000}, {t, 0, 1,  .2}];\)\), "\[IndentingNewLine]", 
    \(\(ListContourPlot[Re[Rrlist], \ PlotRange \[Rule] All, 
        Contours \[Rule] 20, ContourShading \[Rule] False, 
        FrameTicks \[Rule] {ticks, ticks, None, None}, 
        FrameLabel \[Rule] {"\<t3[fs]\>", "\<t1[fs]\>"}];\)\), "\
\[IndentingNewLine]", 
    \(\(ListContourPlot[Re[Rnrlist], \ PlotRange \[Rule] All, 
        Contours \[Rule] 20, ContourShading \[Rule] False, 
        FrameTicks \[Rule] {ticks, ticks, None, None}, 
        FrameLabel \[Rule] {"\<t3[fs]\>", "\<t1[fs]\>"}];\)\)}], "Input"],

Cell["\<\
Perform 2D Fourier transform and re-order data so that w1=w3=0 is centerd in \
the middle.Frequency axis w1 is inverted. Only the upper-right quadrant is \
kept\
\>", "Text"],

Cell[BoxData[{
    \(\(spectrum2Dr = Fourier[Rrlist];\)\), "\[IndentingNewLine]", 
    \(\(spectrum2Dr = 
        Reverse[Drop[RotateRight[spectrum2Dr, {nt/2, nt/2}], 1, 
            1]];\)\), "\[IndentingNewLine]", 
    \(\(spectrum2Dr = 
        Drop[spectrum2Dr, nt/2 - 1, 
          nt/2 - 1];\)\ \ \ \[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(spectrum2Dnr = Fourier[Rnrlist];\)\), "\[IndentingNewLine]", 
    \(\(spectrum2Dnr = 
        Drop[RotateRight[spectrum2Dnr, {nt/2, nt/2}], 1, 
          1];\)\), "\[IndentingNewLine]", 
    \(\(spectrum2Dnr = 
        Drop[spectrum2Dnr, nt/2 - 1, 
          nt/2 - 1];\)\ \ \ \[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(spectrum2Dabs = Re[spectrum2Dr + spectrum2Dnr];\)\)}], "Input"],

Cell["Cut out the spectral range of interest", "Text"],

Cell[BoxData[{
    \(\(nminy = 115;\)\), "\[IndentingNewLine]", 
    \(\(nmaxy = 115;\)\), "\[IndentingNewLine]", 
    \(\(nminx = 111;\)\), "\[IndentingNewLine]", 
    \(\(nmaxx = 119;\)\), "\[IndentingNewLine]", 
    \(\(spectrum2Dabs = 
        Drop[Drop[spectrum2Dabs, nminy, 
            nminx], \(-nmaxy\), \(-nmaxx\)];\)\)}], "Input"],

Cell["Plot purely absorptive spectrum", "Text"],

Cell[BoxData[{\(max = 
        Max[Max[spectrum2Dabs], \(-Min[
              spectrum2Dabs]\)];\), "\[IndentingNewLine]", \(ticksy = 
        Table[{\ w* .188*nt*\(dt/2\)/Pi + 1 - nminy, w}, {w, 0, 6000, 
            150}];\), "\[IndentingNewLine]", \(ticksx = 
        Table[{\ w* .188*nt*\(dt/2\)/Pi + 1 - nminx, w}, {w, 0, 6000, 
            150}];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"p1", "=", 
        RowBox[{"ListContourPlot", "[", 
          RowBox[{
          "spectrum2Dabs", ",", " ", \(PlotRange \[Rule] {0, max}\), 
            ",", \(ContourShading \[Rule] False\), 
            ",", \(Contours \[Rule] 10\), ",", \(Ticks \[Rule] None\), 
            ",", \(ContourStyle \[Rule] {RGBColor[0, 0, 1]}\), ",", 
            StyleBox[\(DisplayFunction -> Identity\),
              "MR"]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"p2", "=", 
        RowBox[{"ListContourPlot", "[", 
          RowBox[{
          "spectrum2Dabs", ",", " ", \(PlotRange \[Rule] {\(-max\), 0}\), 
            ",", \(ContourShading \[Rule] False\), 
            ",", \(Contours \[Rule] 10\), ",", \(Ticks \[Rule] None\), 
            ",", \(ContourStyle \[Rule] {RGBColor[1, 0, 0]}\), ",", 
            StyleBox[\(DisplayFunction -> Identity\),
              "MR"]}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(np = 
        Length[spectrum2Dabs];\), "\[IndentingNewLine]", \(Show[p1, p2, 
        PlotRange \[Rule] {{1, np}, {1, np}}, 
        FrameTicks \[Rule] {ticksx, ticksy, None, None}, 
        DisplayFunction \[Rule] $DisplayFunction];\)}], "Input"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1920}, {0, 997}},
WindowSize->{1141, 651},
WindowMargins->{{10, Automatic}, {Automatic, 38}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 106, 3, 86, "Section"],

Cell[CellGroupData[{
Cell[1836, 57, 188, 4, 53, "Subsubtitle"],
Cell[2027, 63, 66, 0, 33, "Text"],
Cell[2096, 65, 161, 2, 30, "Input"],
Cell[2260, 69, 119, 3, 33, "Text"],
Cell[2382, 74, 690, 13, 210, "Input"],
Cell[3075, 89, 75, 0, 33, "Text"],
Cell[3153, 91, 497, 14, 50, "Input"],
Cell[3653, 107, 73, 0, 33, "Text"],
Cell[3729, 109, 1087, 21, 150, "Input"],
Cell[4819, 132, 70, 0, 33, "Text"],
Cell[4892, 134, 386, 7, 90, "Input"],
Cell[5281, 143, 61, 0, 33, "Text"],
Cell[5345, 145, 691, 12, 130, "Input"],
Cell[6039, 159, 96, 2, 33, "Text"],
Cell[6138, 163, 600, 12, 90, "Input"],
Cell[6741, 177, 106, 3, 33, "Text"],
Cell[6850, 182, 738, 15, 90, "Input"],
Cell[7591, 199, 201, 4, 33, "Text"],
Cell[7795, 205, 629, 10, 50, "Input"],
Cell[8427, 217, 192, 4, 33, "Text"],
Cell[8622, 223, 679, 13, 150, "Input"],
Cell[9304, 238, 49, 0, 33, "Text"],
Cell[9356, 240, 627, 11, 110, "Input"],
Cell[9986, 253, 184, 4, 33, "Text"],
Cell[10173, 259, 755, 15, 190, "Input"],
Cell[10931, 276, 54, 0, 33, "Text"],
Cell[10988, 278, 341, 7, 110, "Input"],
Cell[11332, 287, 47, 0, 33, "Text"],
Cell[11382, 289, 1598, 31, 190, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

