(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10363,        251]*)
(*NotebookOutlinePosition[     11072,        275]*)
(*  CellTagsIndexPosition[     11028,        271]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
Concepts and Methods of 2D Infrared Spectroscopy
Peter Hamm and Martin T. Zanni\
\>", "Section"],

Cell[CellGroupData[{

Cell["\<\
This progam was used to produce Figs. 10.6, i.e. the 2D IR lineshape of the \
OH stretch vibration in water, without using the Cumulant expansion  \
\>", "Subsubtitle"],

Cell["Set working directory (you will have to change it)", "Text"],

Cell[BoxData[
    \(\(SetDirectory["\<C:\Dokumente und Einstellungen\p.hamm\Eigene \
Dateien/PCI/projekte/2010/2D-IR Book/SecSimul/SimulWater\>"];\)\)], "Input"],

Cell["\<\
Constants and proportionaltiy factor that translates forces into a frequency \
shift (Eq. 10.4)\
\>", "Text"],

Cell[BoxData[{
    \(\(NA = 6.023*10^23;\)\), "\[IndentingNewLine]", 
    \(\(w0 = 3550;\)\), "\[IndentingNewLine]", 
    \(\(mass = 1.66*10^\(-27\);\)\), "\[IndentingNewLine]", 
    \(\(mH = 1. ;\)\), "\[IndentingNewLine]", 
    \(\(mO = 16. ;\)\), "\[IndentingNewLine]", 
    \(\(mu = mH*mO/\((mH + mO)\);\)\), "\[IndentingNewLine]", 
    \(\(c = 3*10^10;\)\), "\[IndentingNewLine]", 
    \(\(h = 6.626*10^\(-34\);\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalDelta] = 240;\)\), "\[IndentingNewLine]", 
    \(\(fact = 
        Sqrt[9/4 \((\[CapitalDelta]/
                  w0)\)\ 10^18*\(\(10^6/NA^2\)/\((w0*c*h)\)\)/\((mu*
                    mass)\)*10^\(-24\)]/ .188;\)\)}], "Input"],

Cell["Read MD output files generated by Gromacs (see README file)", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"coord", "=", " ", 
        RowBox[{
          StyleBox["ReadList",
            "MR"], 
          "[", \("\<coord.xvg\>", {Real, Real, Real, Real, Real, Real, 
            Real}\), "]"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"force", "=", " ", 
        RowBox[{
          StyleBox["ReadList",
            "MR"], 
          "[", \("\<force.xvg\>", {Real, Real, Real, Real, Real, Real, 
            Real}\), "]"}]}], ";"}]}], "Input"],

Cell["\<\
Calculate frequency shift according to Eqs. 10.2 and 10.4 subtract mean of \
it, and translate it in units of [ps-1]. Take only time points separated by 4 \
step to save computation time\
\>", "Text"],

Cell[BoxData[{
    \(\(n = Length[force];\)\), "\[IndentingNewLine]", 
    \(\(dt = \((force[\([2, 1]\)] - 
            force[\([1, 1]\)])\);\)\), "\[IndentingNewLine]", 
    \(\(bondOH = 
        Table[{coord[\([i, 5]\)] - coord[\([i, 2]\)], 
            coord[\([i, 6]\)] - coord[\([i, 3]\)], 
            coord[\([i, 7]\)] - coord[\([i, 4]\)]}\ , {i, 1, 
            n}];\)\), "\[IndentingNewLine]", 
    \(\(length = 
        Sqrt[bondOH[\([1, 1]\)]^2 + bondOH[\([1, 2]\)]^2 + 
            bondOH[\([1, 3]\)]^2];\)\), "\[IndentingNewLine]", 
    \(\(forceOH = 
        Table[{\((force[\([i, 5]\)]/mH - force[\([i, 2]\)]/mO)\)*
              mu, \((force[\([i, 6]\)]/mH - force[\([i, 3]\)]/mO)\)*
              mu, \((force[\([i, 7]\)]/mH - force[\([i, 4]\)]/mO)\)*
              mu}\ , {i, 1, n}];\)\), "\[IndentingNewLine]", 
    \(\(step = 4;\)\), "\[IndentingNewLine]", 
    \(\(dt = dt*step;\)\), "\[IndentingNewLine]", 
    \(\(w = \(\(-Table[
                  Sum[\((forceOH[\([i + j, 1]\)]*bondOH[\([i + j, 1]\)] + 
                        forceOH[\([i + j, 2]\)]*bondOH[\([i + j, 2]\)] + 
                        forceOH[\([i + j, 3]\)]*
                          bondOH[\([i + j, 3]\)])\), {j, 0, step - 1}], {i, 
                    1, n - step, step}]\)/step\)/\ length*
          fact;\)\), "\[IndentingNewLine]", 
    \(\(n = Length[w];\)\), "\[IndentingNewLine]", 
    \(\(wmean = Sum[w[\([i]\)], {i, 1, n}]/n;\)\), "\[IndentingNewLine]", 
    \(\(w = \((w - wmean)\)* .188;\)\)}], "Input"],

Cell["\<\
Calculate response functions through the integrals of Eq.10.10, for \
t2=dt*it2. If nstep=1, it will take some time, but gets out the best possible \
signal-to-noise form the 1 ns trajectory. If nstep=10, it is significantly \
faster, but results will be more noisy.\
\>", "Text"],

Cell[BoxData[{
    \(\(it2 = 2;\)\), "\[IndentingNewLine]", 
    \(\(nt = 20;\)\), "\[IndentingNewLine]", 
    \(\(nstep = 10;\)\), "\[IndentingNewLine]", 
    \(\(Rnr = 
        Sum[Table[
                Exp[\(-I\)\ Sum[w[\([is + itau]\)]\ dt, {itau, 1, it1}] - 
                    I\ Sum[w[\([is + itau]\)]\ dt, {itau, it1 + it2 + 1, 
                          it1 + it2 + it3}]]\ , {it1, 0, nt - 1}, {it3, 0, 
                  nt - 1}], {is, 1, n - 200, nstep}]/\((n - 200. )\)*
          nstep;\)\), "\[IndentingNewLine]", 
    \(ListContourPlot[Re[Rnr], \ PlotRange \[Rule] All, Contours \[Rule] 20, 
      ContourShading \[Rule] False, FrameTicks \[Rule] None, 
      FrameLabel \[Rule] {t3, t1}]\), "\[IndentingNewLine]", 
    \(\(Rr = 
        Sum[Table[
                Exp[\(+I\)\ Sum[w[\([is + itau]\)]\ dt, {itau, 1, it1}] - 
                    I\ Sum[w[\([is + itau]\)]\ dt, {itau, it1 + it2 + 1, 
                          it1 + it2 + it3}]]\ , {it1, 0, nt - 1}, {it3, 0, 
                  nt - 1}], {is, 1, n - 200, nstep}]/\((n - 200. )\)*
          nstep;\)\), "\[IndentingNewLine]", 
    \(ListContourPlot[Re[Rr], \ PlotRange \[Rule] All, Contours \[Rule] 20, 
      ContourShading \[Rule] False, FrameTicks \[Rule] None, 
      FrameLabel \[Rule] {t3, t1}]\), "\[IndentingNewLine]", 
    \(\(For[i = 1, i <= nt, \(i++\), Rnr[\([i, 1]\)] /= 2; 
        Rr[\([i, 1]\)] /= 2];\)\), "\[IndentingNewLine]", 
    \(\(For[i = 2, i <= nt, \(i++\), Rnr[\([1, i]\)] /= 2; 
        Rr[\([1, i]\)] /= 2];\)\)}], "Input"],

Cell["\<\
Add anharmonically shifted term to it (Eq. 10.10). Note that we shift both \
peaks by +/-\[CapitalDelta]/2, rather than just the 1-2 peak by -\
\[CapitalDelta]. This is to center the spectrum as much as possible in teh \
very small frequency we use to save computation time. For the same reason, we \
the mean frequency wmean is not added, which allows us to us a much longer \
time-step.\
\>", "Text"],

Cell[BoxData[{
    \(\(RnrAnh = 
        Table[\ Rnr[\([it1, 
                it3]\)]*\((Exp[\(-I\)*\[CapitalDelta]/2* .188*
                    dt*\((it3 - 1)\)] - 
                Exp[I*\[CapitalDelta]/2* .188*dt*\((it3 - 1)\)])\), \ {it1, 
            1, nt}, {it3, 1, nt}];\)\), "\[IndentingNewLine]", 
    \(\(RrAnh = 
        Table[\ Rr[\([it1, 
                it3]\)]*\((Exp[\(-I\)*\[CapitalDelta]/2* .188*
                    dt*\((it3 - 1)\)] - 
                Exp[I*\[CapitalDelta]/2* .188*dt*\((it3 - 1)\)])\), \ {it1, 
            1, nt}, {it3, 1, nt}];\)\)}], "Input"],

Cell["\<\
Perform 2D Fourier transform and re-order data so that w1=w3=0 is centerd in \
the middle. Frequency axis w1 is inverted.\
\>", "Text"],

Cell[BoxData[{
    \(\(spectrum2Dr = Fourier[RrAnh];\)\), "\[IndentingNewLine]", 
    \(\(spectrum2Dr = 
        Reverse[Drop[RotateRight[spectrum2Dr, {nt/2, nt/2}], 1, 
            1]];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(spectrum2Dnr = Fourier[RnrAnh];\)\), "\[IndentingNewLine]", 
    \(\(spectrum2Dnr = 
        Drop[RotateRight[spectrum2Dnr, {nt/2, nt/2}], 1, 
          1];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(spectrum2Dabs = Re[spectrum2Dr + spectrum2Dnr];\)\)}], "Input"],

Cell["Plot purely absorptive spectrum", "Text"],

Cell[BoxData[{\(ticks = 
        Table[{\ w* .188*nt*\(dt/2\)/Pi + nt/2, w}, {w, \(-300\), 300, 
            150}];\), "\[IndentingNewLine]", \(max = 
        Max[{Max[
              spectrum2Dabs], \(-Min[
                spectrum2Dabs]\)}];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"p1", "=", 
        RowBox[{"ListContourPlot", "[", 
          RowBox[{
          "spectrum2Dabs", ",", " ", \(PlotRange \[Rule] {0, max}\), 
            ",", \(ContourShading \[Rule] False\), 
            ",", \(Contours \[Rule] 5\), ",", \(Ticks \[Rule] None\), 
            ",", \(ContourStyle \[Rule] {RGBColor[0, 0, 1]}\), ",", 
            StyleBox[\(DisplayFunction -> Identity\),
              "MR"]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"p2", "=", 
        RowBox[{"ListContourPlot", "[", 
          RowBox[{
          "spectrum2Dabs", ",", " ", \(PlotRange \[Rule] {\(-max\), 0}\), 
            ",", \(ContourShading \[Rule] False\), 
            ",", \(Contours \[Rule] 5\), ",", \(Ticks \[Rule] None\), 
            ",", \(ContourStyle \[Rule] {RGBColor[1, 0, 0]}\), ",", 
            StyleBox[\(DisplayFunction -> Identity\),
              "MR"]}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(Show[{p1, p2}, 
        FrameTicks \[Rule] {ticks, ticks, None, None}, 
        PlotRange \[Rule] {{1, nt - 1}, {1, nt - 1}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)}], "Input"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1920}, {0, 997}},
WindowSize->{1014, 651},
WindowMargins->{{Automatic, 266}, {Automatic, 19}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 106, 3, 86, "Section"],

Cell[CellGroupData[{
Cell[1836, 57, 178, 3, 53, "Subsubtitle"],
Cell[2017, 62, 66, 0, 33, "Text"],
Cell[2086, 64, 161, 2, 30, "Input"],
Cell[2250, 68, 119, 3, 33, "Text"],
Cell[2372, 73, 690, 13, 210, "Input"],
Cell[3065, 88, 75, 0, 33, "Text"],
Cell[3143, 90, 497, 14, 50, "Input"],
Cell[3643, 106, 210, 4, 33, "Text"],
Cell[3856, 112, 1509, 28, 290, "Input"],
Cell[5368, 142, 290, 5, 52, "Text"],
Cell[5661, 149, 1532, 27, 270, "Input"],
Cell[7196, 178, 412, 7, 52, "Text"],
Cell[7611, 187, 583, 12, 50, "Input"],
Cell[8197, 201, 145, 3, 33, "Text"],
Cell[8345, 206, 519, 9, 150, "Input"],
Cell[8867, 217, 47, 0, 33, "Text"],
Cell[8917, 219, 1430, 29, 150, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

